###########
Black Mamba
###########


Build status
============

.. image:: https://travis-ci.org/zrzka/blackmamba.svg?branch=master
    :alt: Travis CI Build Status

.. image:: https://readthedocs.org/projects/blackmamba/badge/?version=latest
    :target: http://blackmamba.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status


Documentation
=============

Everything you need to know is available in the `Black Mamba Documentation <http://blackmamba.readthedocs.io/>`_.
